@@ -62,57 +62,73 @@ class RenderspecContextFunctionTests(unittest.TestCase):
          'oslo.config', None, ('py', 'py3'),
          'python-oslo.config python3-oslo.config'),
         # with version
-        ({'spec_style': 'suse', 'epochs': {}, 'requirements': {}},
+        ({'epochs': {}, 'requirements': {}},
          'oslo.config', ('>=', '1.2.3'), None, 'python-oslo.config >= 1.2.3'),
         ({'spec_style': 'fedora', 'epochs': {}, 'requirements': {}},
          'oslo.config', ('==', '1.2.3~a0'), None,
          'python-oslo-config == 1.2.3~a0'),
         # with version, with epoch
-        ({'spec_style': 'suse', 'epochs': {'oslo.config': 4},
+        ({'epochs': {'oslo.config': 4},
           'requirements': {}},
          'oslo.config', ('>=', '1.2.3'), None,
          'python-oslo.config >= 4:1.2.3'),
         # without version, with epoch
-        ({'spec_style': 'suse', 'epochs': {'oslo.config': 4},
+        ({'epochs': {'oslo.config': 4},
           'requirements': {}},
          'oslo.config', None, None, 'python-oslo.config'),
         # with version, with requirements
-        ({'spec_style': 'suse', 'epochs': {},
+        ({'epochs': {},
           'requirements': {'oslo.config' '1.2.3'}},
          'oslo.config', ('>=', '4.5.6'), None, 'python-oslo.config >= 4.5.6'),
         # without version, with requirements
-        ({'spec_style': 'suse', 'epochs': {},
+        ({'epochs': {},
           'requirements': {'oslo.config': '1.2.3'}},
          'oslo.config', None, None, 'python-oslo.config >= 1.2.3'),
         # without version, with requirements, with epoch
-        ({'spec_style': 'suse', 'epochs': {'oslo.config': 4},
+        ({'epochs': {'oslo.config': 4},
           'requirements': {'oslo.config': '1.2.3'}},
          'oslo.config', None, None, 'python-oslo.config >= 4:1.2.3'),
         # with version, with requirements, with epoch
-        ({'spec_style': 'suse', 'epochs': {'oslo.config': 4},
+        ({'epochs': {'oslo.config': 4},
           'requirements': {'oslo.config' '1.2.3'}},
          'oslo.config', ('>=', '4.5.6'), None,
          'python-oslo.config >= 4:4.5.6'),
         # with version, with requirements, with epoch, python2
-        ({'spec_style': 'suse', 'epochs': {'oslo.config': 4},
+        ({'epochs': {'oslo.config': 4},
           'requirements': {'oslo.config' '1.2.3'}},
          'oslo.config', ('>=', '4.5.6'), 'py2',
          'python2-oslo.config >= 4:4.5.6'),
         # with version, with requirements, with epoch, python3
-        ({'spec_style': 'suse', 'epochs': {'oslo.config': 4},
+        ({'epochs': {'oslo.config': 4},
           'requirements': {'oslo.config' '1.2.3'}},
          'oslo.config', ('>=', '4.5.6'), 'py3',
          'python3-oslo.config >= 4:4.5.6'),
+        # with version, with requirements, python3, skip python3
+        ({'epochs': {}, 'skip_pyversion': 'py3',
+          'requirements': {'oslo.config' '1.2.3'}},
+         'oslo.config', ('>=', '4.5.6'), 'py3',
+         ''),
         # with version, with requirements, with epoch, python2 and python3
-        ({'spec_style': 'suse', 'epochs': {'oslo.config': 4},
+        ({'epochs': {'oslo.config': 4},
           'requirements': {'oslo.config' '1.2.3'}},
          'oslo.config', ('>=', '4.5.6'), ['py2', 'py3'],
          'python2-oslo.config >= 4:4.5.6 python3-oslo.config >= 4:4.5.6'),
-
+        # with version, with requirements, python2 and python3, skip python3
+        ({'epochs': {'oslo.config': 4}, 'skip_pyversion': 'py3',
+          'requirements': {'oslo.config' '1.2.3'}},
+         'oslo.config', ('>=', '4.5.6'), ['py2', 'py3'],
+         'python2-oslo.config >= 4:4.5.6'),
+        # with version, with requirements, python2 and python3, skip python2
+        ({'epochs': {'oslo.config': 4}, 'skip_pyversion': 'py2',
+          'requirements': {'oslo.config' '1.2.3'}},
+         'oslo.config', ('>=', '4.5.6'), ['py2', 'py3'],
+         'python3-oslo.config >= 4:4.5.6'),
     )
     @unpack
     def test_context_py2pkg(self, context, pkg_name, pkg_version,
                             py_versions, expected_result):
+        context.setdefault('skip_pyversion', ())
+        context.setdefault('spec_style', 'suse')
         self.assertEqual(
             renderspec.contextfuncs._context_py2pkg(
                 context, pkg_name, pkg_version, py_versions),
@@ -180,32 +196,32 @@ class RenderspecTemplateFunctionTests(unittest.TestCase):
 
     @data(
         # plain
-        ({'spec_style': 'suse', 'epochs': {}, 'requirements': {}},
+        ({'epochs': {}, 'requirements': {}},
          "{{ py2pkg('requests') }}", "python-requests"),
         # plain, with multiple py_versions
-        ({'spec_style': 'suse', 'epochs': {}, 'requirements': {}},
+        ({'epochs': {}, 'requirements': {}},
          "{{ py2pkg('requests', py_versions=['py2', 'py3']) }}",
          "python2-requests python3-requests"),
         # with version
-        ({'spec_style': 'suse', 'epochs': {}, 'requirements': {}},
+        ({'epochs': {}, 'requirements': {}},
          "{{ py2pkg('requests', ('>=', '2.8.1')) }}",
          "python-requests >= 2.8.1"),
         # with version, with epoch
-        ({'spec_style': 'suse', 'epochs': {'requests': 4}, 'requirements': {}},
+        ({'epochs': {'requests': 4}, 'requirements': {}},
          "{{ py2pkg('requests', ('>=', '2.8.1')) }}",
          "python-requests >= 4:2.8.1"),
         # with version, with epoch, with requirements
-        ({'spec_style': 'suse', 'epochs': {'requests': 4},
+        ({'epochs': {'requests': 4},
           'requirements': {'requests': '1.2.3'}},
          "{{ py2pkg('requests', ('>=', '2.8.1')) }}",
          "python-requests >= 4:2.8.1"),
         # without version, with epoch, with requirements
-        ({'spec_style': 'suse', 'epochs': {'requests': 4},
+        ({'epochs': {'requests': 4},
           'requirements': {'requests': '1.2.3'}},
          "{{ py2pkg('requests') }}",
          "python-requests >= 4:1.2.3"),
         # without version, with epoch, with requirements, with py_versions
-        ({'spec_style': 'suse', 'epochs': {'requests': 4},
+        ({'epochs': {'requests': 4},
           'requirements': {'requests': '1.2.3'}},
          "{{ py2pkg('requests', py_versions=['py2']) }}",
          "python2-requests >= 4:1.2.3"),
@@ -213,6 +229,8 @@ class RenderspecTemplateFunctionTests(unittest.TestCase):
     @unpack
     def test_render_func_py2pkg(self, context, string, expected_result):
         template = self.env.from_string(string)
+        context.setdefault('skip_pyversion', ())
+        context.setdefault('spec_style', 'suse')
         self.assertEqual(
             template.render(**context),
             expected_result)
@@ -421,8 +439,8 @@ class RenderspecCommonTests(unittest.TestCase):
             with open(f1, 'w+') as f:
                 f.write(template)
             rendered = renderspec.generate_spec(
-                style, epochs, requirements, 'spec.j2', f1, None)
-            self.assertEqual(rendered, expected_result)
+                style, epochs, requirements, (), 'spec.j2', f1, None)
+            self.assertTrue(rendered.endswith(expected_result))
         finally:
             shutil.rmtree(tmpdir)
 
@@ -484,7 +502,7 @@ class RenderspecDistTeamplatesTests(unittest.TestCase):
             # mock this to use testing dist-tempaltes folder
             mock_dt_path.return_value = dt_dir
 
-            out = renderspec.generate_spec('loldistro', {}, {}, 'spec.j2',
+            out = renderspec.generate_spec('loldistro', {}, {}, (), 'spec.j2',
                                            base_path, None)
             self.assertEqual(out, expected_out)
         finally:
